pub struct InputOptions {
pub instructions: Option<String>,
pub input_text: Option<String>,
pub recipe: Option<String>,
pub system: Option<String>,
pub params: Vec<(String, String)>,
pub additional_sub_recipes: Vec<String>,
pub explain: bool,
pub render_recipe: bool,
}Expand description
Input source and recipe options for the run command
Fields
instructions: Option<String>Path to instruction file containing commands
input_text: Option<String>Input text containing commands
recipe: Option<String>Recipe name or full path to the recipe file
system: Option<String>Additional system prompt to customize agent behavior
params: Vec<(String, String)>additional_sub_recipes: Vec<String>Additional sub-recipe file paths
explain: boolShow the recipe title, description, and parameters
render_recipe: boolPrint the rendered recipe instead of running it