Structs
- Project
Info - Structure to track project information
- Project
Info Display - Project information with path as a separate field for easier access
- Project
Tracker - Structure to hold all tracked projects
Functions
- update_
project_ tracker - Update the project tracker with the current directory and optional instruction