classify_planner_response

Function classify_planner_response 

pub async fn classify_planner_response(
    message_text: String,
    provider: Arc<dyn Provider>,
) -> Result<PlannerResponseType>
Decide if the planner’s reponse is a plan or a clarifying question

This function is called after the planner has generated a response to the user’s message. The response is either a plan or a clarifying question.