pub struct CliSession { /* private fields */ }Implementations
Sourceimpl CliSession
impl CliSession
pub async fn new( agent: Agent, session_id: String, debug: bool, scheduled_job_id: Option<String>, max_turns: Option<u32>, edit_mode: Option<EditMode>, retry_config: Option<RetryConfig>, output_format: String, ) -> Self
pub fn session_id(&self) -> &String
Sourcepub async fn add_extension(&mut self, extension_command: String) -> Result<()>
pub async fn add_extension(&mut self, extension_command: String) -> Result<()>
Add a stdio extension to the session
Arguments
extension_command- Full command string including environment variables Format: “ENV1=val1 ENV2=val2 command args…”
Sourcepub async fn add_streamable_http_extension(
&mut self,
extension_url: String,
) -> Result<()>
pub async fn add_streamable_http_extension( &mut self, extension_url: String, ) -> Result<()>
Sourcepub async fn add_builtin(&mut self, builtin_name: String) -> Result<()>
pub async fn add_builtin(&mut self, builtin_name: String) -> Result<()>
Add a builtin extension to the session
Arguments
builtin_name- Name of the builtin extension(s), comma separated
pub async fn list_prompts( &mut self, extension: Option<String>, ) -> Result<HashMap<String, Vec<String>>>
pub async fn get_prompt_info( &mut self, name: &str, ) -> Result<Option<PromptInfo>>
pub async fn get_prompt( &mut self, name: &str, arguments: Value, ) -> Result<Vec<PromptMessage>>
Sourcepub async fn interactive(&mut self, prompt: Option<String>) -> Result<()>
pub async fn interactive(&mut self, prompt: Option<String>) -> Result<()>
Start an interactive session, optionally with an initial message
Sourcepub async fn headless(&mut self, prompt: String) -> Result<()>
pub async fn headless(&mut self, prompt: String) -> Result<()>
Process a single message and exit
Sourcepub async fn update_completion_cache(&mut self) -> Result<()>
pub async fn update_completion_cache(&mut self) -> Result<()>
Update the completion cache with fresh data This should be called before the interactive session starts
pub fn message_history(&self) -> Conversation
Sourcepub fn render_message_history(&self)
pub fn render_message_history(&self)
Render all past messages from the session history
pub async fn get_session(&self) -> Result<Session>
pub async fn get_total_token_usage(&self) -> Result<Option<i32>>
Sourcepub async fn display_context_usage(&self) -> Result<()>
pub async fn display_context_usage(&self) -> Result<()>
Display enhanced context usage with session totals