pub struct SessionBuilderConfig {Show 21 fields
pub session_id: Option<String>,
pub resume: bool,
pub no_session: bool,
pub extensions: Vec<String>,
pub streamable_http_extensions: Vec<String>,
pub builtins: Vec<String>,
pub extensions_override: Option<Vec<ExtensionConfig>>,
pub additional_system_prompt: Option<String>,
pub settings: Option<SessionSettings>,
pub provider: Option<String>,
pub model: Option<String>,
pub debug: bool,
pub max_tool_repetitions: Option<u32>,
pub max_turns: Option<u32>,
pub scheduled_job_id: Option<String>,
pub interactive: bool,
pub quiet: bool,
pub sub_recipes: Option<Vec<SubRecipe>>,
pub final_output_response: Option<Response>,
pub retry_config: Option<RetryConfig>,
pub output_format: String,
}Expand description
Configuration for building a new Aster session
This struct contains all the parameters needed to create a new session, including session identification, extension configuration, and debug settings.
Fields
session_id: Option<String>Session id, optional need to deduce from context
resume: boolWhether to resume an existing session
no_session: boolWhether to run without a session file
extensions: Vec<String>List of stdio extension commands to add
streamable_http_extensions: Vec<String>List of streamable HTTP extension commands to add
builtins: Vec<String>List of builtin extension commands to add
extensions_override: Option<Vec<ExtensionConfig>>List of extensions to enable, enable only this set and ignore configured ones
additional_system_prompt: Option<String>Any additional system prompt to append to the default
settings: Option<SessionSettings>Settings to override the global Aster settings
provider: Option<String>Provider override from CLI arguments
model: Option<String>Model override from CLI arguments
debug: boolEnable debug printing
max_tool_repetitions: Option<u32>Maximum number of consecutive identical tool calls allowed
max_turns: Option<u32>Maximum number of turns (iterations) allowed without user input
scheduled_job_id: Option<String>ID of the scheduled job that triggered this session (if any)
interactive: boolWhether this session will be used interactively (affects debugging prompts)
quiet: boolQuiet mode - suppress non-response output
sub_recipes: Option<Vec<SubRecipe>>Sub-recipes to add to the session
final_output_response: Option<Response>Final output expected response
retry_config: Option<RetryConfig>Retry configuration for automated validation and recovery
output_format: StringOutput format (text, json)